@@ -1,25 +1,42 @@
 package Random::Any;
 
-our $DATE = '2018-01-01'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2018-01-02'; # DATE
+our $VERSION = '0.003'; # VERSION
 
-use strict;
+use strict 'subs', 'vars';
 #use warnings;
 
-use Exporter qw(import);
-our @EXPORT_OK = qw(rand);
-
+my $warn;
 my $sub;
 
 sub rand(;$) {
+    $sub->(@_);
+}
+
+sub import {
+    my $pkg = shift;
+
+    my $caller = caller();
+
+    while (@_) {
+        my $arg = shift;
+        if ($arg eq '-warn') {
+            $warn = shift;
+        } elsif ($arg eq 'rand') {
+            *{"$caller\::rand"} = \&rand;
+        } else {
+            die "'$_' is not exported by " . __PACKAGE__;
+        }
+    }
+
     unless ($sub) {
         if (eval { require Math::Random::Secure; 1 }) {
             $sub = \&Math::Random::Secure::rand;
         } else {
+            warn __PACKAGE__ . ": Math::Random::Secure is not available: $@, falling back on builtin rand()" if $warn;
             $sub = \&CORE::rand;
         }
     }
-    $sub->(@_);
 }
 
 1;
@@ -37,7 +54,7 @@ Random::Any - Try to use Math::Random::Secure::rand(), fallback on builtin rand(
 
 =head1 VERSION
 
-This document describes version 0.002 of Random::Any (from Perl distribution Random-Any), released on 2018-01-01.
+This document describes version 0.003 of Random::Any (from Perl distribution Random-Any), released on 2018-01-02.
 
 =head1 SYNOPSIS
 
@@ -51,6 +68,12 @@ This module provides a single export C<rand()> that tries to use
 L<Math::Random::Secure>'s C<rand()> first and, if that module is not available,
 falls back on the builtin rand().
 
+=head1 EXPORTS
+
+=head2 -warn => bool
+
+Can be set to true to emit a warning if Math::Random::Secure is not available.
+
 =head1 FUNCTIONS
 
 =head2 rand
